.. SHYBRID documentation master file, created by
   sphinx-quickstart on Thu Jan 23 17:11:41 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

About SHYBRID
=============
SHYBRID is a graphical user interface for the assisted transformation of extracellular brain recordings into so-called hybrid ground truth recordings which are characterized by the availability of partial ground truth spike times. As such, SHYBRID empowers spike sorting users to gain more insight into spike sorting performance and answer other spike sorting related questions for their specific recording setting.

This documentation will focus on installing and using the provided software. If you are interested in a more formal description of the hybrid ground truth model, we refer you to the preprint of our `scientific SHYBRID paper <https://www.biorxiv.org/content/10.1101/734061v1>`_. Feel free to `contact me <mailto:jasper.wouters@esat.kuleuven.be>`_ if you have any questions/doubts related to this documentation or usage of the software. In case you experience issues using SHYBRID or have ideas for new features don't hesitate to open an issue on `GitHub <https://github.com/jwouters91/shybrid>`_ or contact me by e-mail.

.. toctree::
   :maxdepth: 1

   installation
   quickstart
   loading
   sorting
   hybridizing_extra

